BaseNotifier<S> class abstract

Define a base notifier for SimpleNotifier and StateNotifier

Implementers

Constructors

BaseNotifier()

Properties

disposed → bool
Tell us if the notifier was disposed
no setter
hashCode → int
The hash code for this object.
no setteroverride
mounted → bool
Tell us if the notifier is mounted
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → FutureOr<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited