PersistentStateStorage class abstract

this class defines a storage interface for any StateNotifier that implements the PersistentStateMixin

Constructors

PersistentStateStorage()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String key) → Future<void>
delete a cached state from the storage
deleteAll() → Future<void>
delete all states in your storage
get(String key) → Map<String, dynamic>?
return a saved state by key
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(String key, Map<String, dynamic> json) → Future<void>
save the state as a json string
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited