BaseFactoryProvider<E, A> class abstract

Inheritance
Implementers

Constructors

BaseFactoryProvider(CreatorCallback<E, A> callback, {String? debugLabel})

Properties

containerElements → Map<String, Element>
elements saved inside the ProvidersContainer
no setterinherited
creator → Creator<E, A>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

debugLabel({String? tag}) → String
inherited
dispose({String? tag}) → Element<E>?
override
getKey(String? tag) → String
generate a key to be used into the ProvidersContainer
inherited
mounted({String? tag}) → bool
check if the current provider has a valid Element value into the ProvidersContainer
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onElementValueAssigned(Element<E> element, bool autoDispose) → void
inherited
overrideCreator(CreatorCallback<E, A> callback, {bool? autoDispose}) → void
For testing use this to override a provider behavior
inherited
read({String? tag}) → E
return the E associated to the provider, if the E is not saved into the ProvidersContainer the Element will be created
override
setArguments(A args, {String? tag}) → void
save arguments into the provider Ref
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited