Creator<E, A> class

Constructors

Creator(CreatorCallback<E, A> _callback, bool _autoDispose)

Properties

autoDispose → bool
no setter
callback → CreatorCallback<E, A>
no setter
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
overrideCreator(CreatorCallback<E, A> callback, {bool? autoDispose}) → void
resetCreator() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited