StateNotifierTagArgumentsProvider<N extends StateNotifier<S>, S, A> class

Inheritance
Implemented types

Constructors

StateNotifierTagArgumentsProvider(CreatorCallback<N, A> creator, {bool autoDispose = true, String? debugLabel})

Properties

containerElements → Map<String, Element>
elements saved inside the ProvidersContainer
no setterinherited
creator → Creator<N, A>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

debugLabel({String? tag}) → String
inherited
dispose({String? tag}) → Element<N>?
inherited
getKey(String? tag) → String
generate a key to be used into the ProvidersContainer
inherited
mounted({String? tag}) → bool
check if the current provider has a valid Element value into the ProvidersContainer
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onElementValueAssigned(Element<N> element, bool autoDispose) → void
inherited
overrideCreator(CreatorCallback<N, A> callback, {bool? autoDispose}) → void
For testing use this to override a provider behavior
inherited
read({String? tag}) → N
return the E associated to the provider, if the E is not saved into the ProvidersContainer the Element will be created
inherited
setArguments(A args, {String? tag}) → void
save arguments into the provider Ref
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited