Rx<T> class

Rx class to work with observables

Available extensions

Constructors

Rx(T initalValue)
Constructor

Properties

controller → StreamController<T>
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
returns true if the current observable has listeners
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stream → Stream<T>
stream for the current observable
no setter
value ↔ T
returns the current value for this observable
getter/setter pair

Methods

close() → FutureOr<void>
close the StreaMeeduController for this observable
debounce(Duration delay, void callback(T)) → RxReaction

Available on Rx<T>, provided by the RxExtensions extension

Every time that the Rx<T> changes the callback will be called after a delay.
ever(void callback(T), {bool condition(T)?}) → RxReaction

Available on Rx<T>, provided by the RxExtensions extension

callback is called every time that the Rx<T> changes.
interval(Duration duration, void callback(T)) → RxReaction

Available on Rx<T>, provided by the RxExtensions extension

the callback will be called every certain time interval ignoring the other changes
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
once(void callback(T), {bool condition(T)?}) → RxReaction

Available on Rx<T>, provided by the RxExtensions extension

the callback will be executed only 1 time
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited