RxNotifier<T> class

class to add dynamic updates into a RxBuilder widget

Annotations
  • @sealed

Constructors

RxNotifier()

Properties

canUpdate → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject ↔ Rx<T?>
getter/setter pair
subscriptions → Map<Rx, List<StreamSubscription>>
no setter

Methods

addListener(Rx<T> rx) → void
close() → FutureOr<void>
Closes the subscriptions for this Rx, releasing the resources.
listen(void _(T?)) → StreamSubscription<T?>
used by the RxBuilder to listen the changes in a observable
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

proxy ↔ RxNotifier?
used to create a tmp RxNotifier since a RxBuilder Widget
getter/setter pair